cole Library Reference Manual
Prev |  | Next

# Internals

## Name

Internals -- cole internals - don't trust in anything here, because it may (and will) change.

## Synopsis

    struct      COLEFS;
    struct      COLEDIRENT;
    struct      COLEDIR;
    struct      COLEFILE;
    #define     F32
    #define     F64
    #define     U8
    #define     U16
    #define     U32
    U16         fil_sreadU16                    (U8 *in);
    U32         fil_sreadU32                    (U8 *in);
    F64         fil_sreadF64                    (U8 *in);
    void        fil_swriteU16                   (U8 *dest,
                                                 U16 *src);
    void        fil_swriteU32                   (U8 *dest,
                                                 U32 *src);
    #define     verbose_return                  ()
    #define     test                            (t,retval)
    #define     test_exitf                      (t,retval,func)
    #define     test_call                       (t,typeretval)
    #define     test_call_exitf                 (t,typeretval,func)
    #define     report_bug                      (prog)
    #define     assert_return                   (prog,t,retval)
    #define     verbose_d                       (n)
    #define     verbose                         (s)
    #define     verbose_wonl                    (s)
    #define     verboseU8                       (expr)
    #define     verboseU16                      (expr)
    #define     verboseU32                      (expr)
    #define     verboseS                        (expr)
    #define     verboseS_wonl                   (expr)
    #define     warning                         (t)
    #define     verboseU32Array                 (array,len)
    #define     verboseU8Array_force            (rec,len,reclen)
    #define     verboseU8Array                  (rec,len,reclen)

## Description

Contains calls to access directly the file system, and endianess care calls.

## Details

### struct COLEFS

    struct COLEFS {
    	/* This structure is for internal use only, not for the public API */
    	pps_entry *tree;
    	U32 root;			/* entry root, root pps_entry */
    	U8 *BDepot;
    	U8 *SDepot;
    	FILE *sbfile;
    	char *sbfilename;
    	FILE *file;			/* actual file (the filesystem) */
    };

### struct COLEDIRENT

    struct COLEDIRENT {
    	/* This structure is for internal use only, not for the public API */
    	U32 entry;
    	struct _COLEDIR *dir;		/* father */
    };

### struct COLEDIR

    struct COLEDIR {
    	/* This structure is for internal use only, not for the public API */
    	U32 entry;
    	struct _COLEDIRENT visited_entry;
    	struct _COLEFS *fs;		/* father */
    };

### struct COLEFILE

    struct COLEFILE {
    	/* This structure is for internal use only, not for the public API */
    	U32 entry;
    	FILE *file;			/* actual extracted file */
    	char *filename;			/* actual extracted file's name */
    	U32 filesize;			/* actual extracted file size */
    	struct _COLEFS *fs;		/* father */
    	U32 pos;			/* file pointer position */
    };

### F32

    #define     F32

### F64

    #define     F64

### U8

    #define U8      unsigned char

### U16

    #define     U16

### U32

    #define     U32

### fil_sreadU16 ()

    U16         fil_sreadU16                    (U8 *in);

`in` : |
Returns : |

### fil_sreadU32 ()

    U32         fil_sreadU32                    (U8 *in);

`in` : |
Returns : |

### fil_sreadF64 ()

    F64         fil_sreadF64                    (U8 *in);

`in` : |
Returns : |

### fil_swriteU16 ()

    void        fil_swriteU16                   (U8 *dest,
                                                 U16 *src);

`dest` : |
`src` : |

### fil_swriteU32 ()

    void        fil_swriteU32                   (U8 *dest,
                                                 U32 *src);

`dest` : |
`src` : |

### verbose_return()

    #define     verbose_return()

### test()

    #define     test(t,retval)

`t` : |
`retval` : |

### test_exitf()

    #define     test_exitf(t,retval,func)

`t` : |
`retval` : |
`func` : |

### test_call()

    #define     test_call(t,typeretval)

`t` : |
`typeretval` : |

### test_call_exitf()

    #define     test_call_exitf(t,typeretval,func)

`t` : |
`typeretval` : |
`func` : |

### report_bug()

    #define     report_bug(prog)

`prog` : |

### assert_return()

    #define     assert_return(prog,t,retval)

`prog` : |
`t` : |
`retval` : |

### verbose_d()

    #define     verbose_d(n)

`n` : |

### verbose()

    #define     verbose(s)

`s` : |

### verbose_wonl()

    #define     verbose_wonl(s)

`s` : |

### verboseU8()

    #define     verboseU8(expr)

`expr` : |

### verboseU16()

    #define     verboseU16(expr)

`expr` : |

### verboseU32()

    #define     verboseU32(expr)

`expr` : |

### verboseS()

    #define     verboseS(expr)

`expr` : |

### verboseS_wonl()

    #define     verboseS_wonl(expr)

`expr` : |

### warning()

    #define     warning(t)

`t` : |

### verboseU32Array()

    #define     verboseU32Array(array,len)

`array` : |
`len` : |

### verboseU8Array_force()

    #define     verboseU8Array_force(rec,len,reclen)

`rec` : |
`len` : |
`reclen` : |

### verboseU8Array()

    #define     verboseU8Array(rec,len,reclen)

`rec` : |
`len` : |
`reclen` : |

Prev | Home | Next
API | Up | Bugs